@@ -1,9 +1,15 @@
 import unittest
+import os
 from file_checksum import Checksum
 
 file = 'test.txt'
-with open(file, 'w') as test_file:
-    print("test", file=test_file)
+
+def setup_module(module):
+    with open(file, 'w') as test_file:
+        print("test", file=test_file)
+
+def teardown_module(module):
+    os.remove(file)
 
 class TestChecksum(unittest.TestCase):
 
